@@ -13,6 +13,7 @@ import re
 from itertools import chain
 from more_itertools import locate
 regex = re.compile('[^a-zA-Z]')
+import sys
 
 
 class PeptideSearch():
@@ -80,7 +81,12 @@ class PeptideSearch():
         pept=list()
         start=list()
         count=0
-        for i in Peptides:
+        sys.stdout.write("[progress: ")
+        for j in range(len(Peptides)):
+            if j%800==0:
+                sys.stdout.write(" %"+str(round(j/len(Peptides)*100)))
+                sys.stdout.flush()
+            i=Peptides[j]
             string_ind = list(locate(DBString, lambda a: i in a))
             if len(string_ind)>0:
                 count=count+1
@@ -92,7 +98,7 @@ class PeptideSearch():
         string_index = list(chain.from_iterable(L))
         start_index=list((start))
           
-        
+        sys.stdout.write("step1]\n")
         a = np.array(peptide)
         _, idx = np.unique(a, return_index=True)
         lista= a[np.sort(idx)]
@@ -110,6 +116,9 @@ class PeptideSearch():
         df = pd.DataFrame( columns = ['Peptide','geneid/s', 'start/s', 'ExactMatch/OneMismatch'])
         j=0
         for i in range(len(lista)):
+            if i%200==0:
+                sys.stdout.write(":")
+                sys.stdout.flush()
             start_ends=''
             geneid=''
             Occurances= count[i]
@@ -120,6 +129,7 @@ class PeptideSearch():
                 start_ends = str(start_index[j])+ '--'+ str(start_index[j]+len(lista[i]))
                 j=j+1
                 df = df.append({'Peptide':lista[i],'geneid/s':geneid, 'start/s':start_ends, 'ExactMatch/OneMismatch':'ExactMatch'}, ignore_index=True)
+        sys.stdout.write(" Done!]\n")
         return df, pList
 
     #find matches with one mismatch for a list of peptides in the Fasta_File
@@ -131,7 +141,11 @@ class PeptideSearch():
         DBString=db['sequence']
         df=pd.DataFrame()
         NoMatch=set()
+        sys.stdout.write("This might take a while for large number of peptides, use ctrl+c if you want to interupt the script \n [Progress:")
         for i in range(len(peptides)):
+            if i%300==0:
+                sys.stdout.write(" %"+str(round(i/len(peptides)*100)))
+                sys.stdout.flush()
             strp= peptides[i]            
             for q in range(len(strp)):
                 str1= strp[0:q]
@@ -155,6 +169,7 @@ class PeptideSearch():
                             df=df.append(dfrelay1,ignore_index=True)
                     else:
                         NoMatch.add(strp)
+        sys.stdout.write(" Done!]\n")
                             
 
 
@@ -198,9 +213,9 @@ class PeptideSearch():
         return Result, Index   
                     
 
-# List=["ACH", "K"]
-# p= PeptideSearch(List, "Test.fasta",)
-# df, pList= p.ExactMatch(List)
+#List=["ACH", "K"]
+#p= PeptideSearch("Peptides.txt", "Mtb.H37Rv.faFrame1Direct.txt")
+#df, pList= p.OneMismatch(List)
 # df2, N= p.OneMismatch(List)
 # d, s= PeptideSearch.SequenceSearchs("sl", "abcsm")
 
